from .errorhandler import register_error_handlers
from .helpers import BaseItemView, BaseModel, CustomFlask, PaginationMixin, register_api, register_blueprints
from .response import ok_resp

__all__ = (
    'BaseItemView',
    'BaseModel',
    'CustomFlask',
    'PaginationMixin',
    'register_api',
    'register_blueprints',
    'ok_resp',
    'register_error_handlers',
)



import re

from wtforms.validators import URL, UUID, AnyOf
from wtforms.validators import DataRequired as DataRequired_
from wtforms.validators import Email, EqualTo, InputRequired, IPAddress, Length, MacAddress, NoneOf, NumberRange
from wtforms.validators import Optional as Optional_
from wtforms.validators import (
    Regexp, StopValidation, ValidationError, any_of, email, equal_to, input_required, ip_address, length, mac_address,
    none_of, number_range, regexp, url)

__all__ = (
    'DataRequired', 'Email', 'email', 'EqualTo', 'equal_to',
    'IPAddress', 'ip_address', 'InputRequired', 'input_required', 'Length',
    'length', 'NumberRange', 'number_range', 'Optional',
    'Regexp', 'regexp', 'URL', 'url', 'AnyOf',
    'any_of', 'NoneOf', 'none_of', 'MacAddress', 'mac_address', 'UUID',
    'ValidationError', 'StopValidation', 'PhoneNumber', 'Range'
)

PHONE_REGEX = r'^1[3-9]\d{9}$'
PHONE_PATERN = re.compile(PHONE_REGEX)


class PhoneNumber(Regexp):
    def __init__(self):
        super().__init__(PHONE_PATERN, message='无效的手机号')


class DataRequired(DataRequired_):
    def __call__(self, form, field):
        if field.data is None or isinstance(field.data, str) and not field.data.strip():
            if self.message is None:
                message = field.gettext('This field is required.')
            else:
                message = self.message

            field.errors[:] = []
            raise StopValidation(message)


class Optional(Optional_):
    def __call__(self, form, field):
        if field.data is None or isinstance(field.data, str) and not self.string_check(field.data):
            field.errors[:] = []
            raise StopValidation


class Range(object):
    def __init__(self, min=None, max=None, message=None):
        self.min = min
        self.max = max
        self.message = message

    def __call__(self, form, field):
        data = field.data
        if data is None or (self.min is not None and data < self.min) or \
                (self.max is not None and data > self.max):
            message = self.message
            if message is None:
                # we use %(min)s interpolation to support floats, None, and
                # Decimals without throwing a formatting exception.
                if self.max is None:
                    message = field.gettext('不能小于 %(min)s.')
                elif self.min is None:
                    message = field.gettext('不能大于 %(max)s.')
                else:
                    message = field.gettext('必须在 %(min)s 和 %(max)s之间.')

            raise ValidationError(message % dict(min=self.min, max=self.max))



from datetime import datetime

from wtforms import DateField as DateField_
from wtforms import DateTimeField as DateTimeField_
from wtforms import DecimalField, Field, FloatField
from wtforms import IntegerField as IntegerField_
from wtforms import PasswordField
from wtforms import SelectField as SelectField_
from wtforms import SelectMultipleField

__all__ = (
    'BooleanField',
    'DateField',
    'DateTimeField',
    'DecimalField',
    'Field',
    'FloatField',
    'IntegerField',
    'ListField',
    'PasswordField',
    'SelectField',
    'SelectMultipleField',
    'StringField',
)


class StringField(Field):
    def process_data(self, value):
        if value is None:
            self.data = value
            return
        if not isinstance(value, str):
            self.data = None
            raise ValueError('不是字符串')
        self.data = value


class IntegerField(IntegerField_):
    def process_data(self, value):
        if value is None:
            self.data = None
            return
        try:
            self.data = int(value)
        except (ValueError, TypeError):
            self.data = None
            raise ValueError(self.gettext('Not a valid integer value'))


class BooleanField(Field):
    def process_data(self, value):
        self.data = bool(value)


class StrictBooleanField(Field):
    def process_data(self, value):
        self.data = value
        if not isinstance(value, bool):
            raise ValueError('不是有效的bool类型')


class SelectField(SelectField_):
    def process_data(self, value):
        if value is None:
            self.data = value
        else:
            super().process_data(value)


class DateTimeField(DateTimeField_):
    def process_data(self, value):
        if not value:
            self.data = None
            return
        try:
            self.data = datetime.strptime(value, self.format)
        except ValueError:
            self.data = None
            raise ValueError(self.gettext('Not a valid datetime value'))


class DateField(DateField_):
    def process_data(self, value):
        if not value:
            self.data = None
            return
        try:
            self.data = datetime.strptime(value, self.format).date()
        except ValueError:
            self.data = None
            raise ValueError(self.gettext('Not a valid date value'))


class ListField(Field):
    def process_data(self, value):
        if not (value is None or isinstance(value, list)):
            self.data = None
            raise ValueError('不是有效的列表')
        self.data = value



from flask import request
from wtforms import Form

from ..exceptions import FormValidationError

__all__ = (
    'BaseItemForm',
    'BaseQueryForm',
    'Form',
    'JSONForm',
)


class JSONForm(Form):
    class Meta:
        locales = ['zh']

    def __init__(self):
        data = request.get_json()
        super().__init__(data=data)

    def check(self):
        if not self.validate():
            raise FormValidationError(self)


class BaseItemForm(JSONForm):
    def __init__(self, item):
        self.item = item
        super().__init__()

    def resp(self):
        self.check()
        item = self.save()
        return item.todict()


class BaseQueryForm(Form):
    def __init__(self):
        super().__init__(formdata=request.args)



#!/usr/bin/env python
from setuptools import find_packages, setup

with open('README.rst') as f:
    readme = f.read()


setup(
    name='Flask-ZS',
    version='0.0.11',
    description='A helpers for Flask.',
    long_description=readme,
    author='codeif',
    author_email='me@codeif.com',
    url='https://github.com/codeif/flask-zs',
    license='MIT',
    install_requires=['requests', 'flask', 'WTForms', 'SQLAlchemy'],
    packages=find_packages(exclude=('example',)),
)
